<a id="toolbar.*"></a>

## \*

<a id="toolbar.qta"></a>

## qta

<a id="toolbar.location_map"></a>

#### location\_map

<a id="toolbar.BaseToolbar"></a>

## BaseToolbar Objects

```python
class BaseToolbar(QToolBar)
```

<a id="toolbar.BaseToolbar.__init__"></a>

#### \_\_init\_\_

```python
def __init__(parent=None, name=None, location=None, size=40)
```

<a id="toolbar.BaseToolbar.add_spacer"></a>

#### add\_spacer

```python
def add_spacer()
```

<a id="toolbar.SettingsToolbar"></a>

## SettingsToolbar Objects

```python
class SettingsToolbar(BaseToolbar)
```

<a id="toolbar.SettingsToolbar.__init__"></a>

#### \_\_init\_\_

```python
def __init__(*args, **kwargs)
```

<a id="toolbar.SettingsToolbar.add_action"></a>

#### add\_action

```python
def add_action(action)
```

<a id="toolbar.SettingsToolbar.add_separator"></a>

#### add\_separator

```python
def add_separator()
```

